@@ -1,12 +1,18 @@
 from datetime import datetime
 
-
 from celery import conf
 from celery.backends.base import BaseDictBackend
 from celery.db.models import Task, TaskSet
 from celery.db.session import ResultSession
 from celery.exceptions import ImproperlyConfigured
 
+try:
+    import sqlalchemy as _
+except ImportError:
+    raise ImproperlyConfigured(
+        "The database result backend requires SQLAlchemy to be installed."
+        "See http://pypi.python.org/pypi/SQLAlchemy")
+
 
 class DatabaseBackend(BaseDictBackend):
     """The database result backend."""
@@ -81,6 +87,15 @@ class DatabaseBackend(BaseDictBackend):
         finally:
             session.close()
 
+    def _forget(self, task_id):
+        """Forget about result."""
+        session = self.ResultSession()
+        try:
+            session.query(Task).filter(Task.task_id == task_id).delete()
+            session.commit()
+        finally:
+            session.close()
+
     def cleanup(self):
         """Delete expired metadata."""
         session = self.ResultSession()
