@@ -6,6 +6,7 @@ Periodic Task Scheduler
 import time
 import shelve
 import threading
+import traceback
 import multiprocessing
 from datetime import datetime
 from UserDict import UserDict
@@ -13,9 +14,10 @@ from UserDict import UserDict
 from celery import log
 from celery import conf
 from celery import platforms
+from celery import registry
 from celery.execute import send_task
 from celery.schedules import maybe_schedule
-from celery.messaging import establish_connection
+from celery.messaging import establish_connection, TaskPublisher
 from celery.utils import instantiate
 from celery.utils.info import humanize_seconds
 
@@ -130,26 +132,29 @@ class Scheduler(UserDict):
 
     """
     Entry = ScheduleEntry
+    Publisher = TaskPublisher
 
     def __init__(self, schedule=None, logger=None, max_interval=None,
-            **kwargs):
+            lazy=False, **kwargs):
         UserDict.__init__(self)
         if schedule is None:
             schedule = {}
         self.data = schedule
         self.logger = logger or log.get_default_logger(name="celery.beat")
         self.max_interval = max_interval or conf.CELERYBEAT_MAX_LOOP_INTERVAL
-        self.setup_schedule()
+        if not lazy:
+            self.setup_schedule()
 
-    def maybe_due(self, entry, connection=None):
+    def maybe_due(self, entry, publisher=None):
         is_due, next_time_to_run = entry.is_due()
 
         if is_due:
             self.logger.debug("Scheduler: Sending due task %s" % entry.task)
             try:
-                result = self.apply_async(entry, connection=connection)
-            except SchedulingError, exc:
-                self.logger.error("Scheduler: %s" % exc)
+                result = self.apply_async(entry, publisher=publisher)
+            except Exception, exc:
+                self.logger.error("Message Error: %s\n%s" % (exc,
+                    traceback.format_stack()))
             else:
                 self.logger.debug("%s sent. id->%s" % (entry.task,
                                                        result.task_id))
@@ -163,15 +168,17 @@ class Scheduler(UserDict):
         """
         remaining_times = []
         connection = establish_connection()
+        publisher = self.Publisher(connection=connection)
         try:
             try:
                 for entry in self.schedule.itervalues():
-                    next_time_to_run = self.maybe_due(entry, connection)
+                    next_time_to_run = self.maybe_due(entry, publisher)
                     if next_time_to_run:
                         remaining_times.append(next_time_to_run)
             except RuntimeError:
                 pass
         finally:
+            publisher.close()
             connection.close()
 
         return min(remaining_times + [self.max_interval])
@@ -180,15 +187,26 @@ class Scheduler(UserDict):
         new_entry = self.schedule[entry.name] = entry.next()
         return new_entry
 
-    def apply_async(self, entry, connection=None, **kwargs):
+    def apply_async(self, entry, publisher=None, **kwargs):
         # Update timestamps and run counts before we actually execute,
         # so we have that done if an exception is raised (doesn't schedule
         # forever.)
         entry = self.reserve(entry)
 
         try:
-            result = self.send_task(entry.task, entry.args, entry.kwargs,
-                                    connection=connection, **entry.options)
+            task = registry.tasks[entry.task]
+        except KeyError:
+            task = None
+
+        try:
+            if task:
+                result = task.apply_async(entry.args, entry.kwargs,
+                                          publisher=publisher,
+                                          **entry.options)
+            else:
+                result = self.send_task(entry.task, entry.args, entry.kwargs,
+                                        publisher=publisher,
+                                        **entry.options)
         except Exception, exc:
             raise SchedulingError("Couldn't apply scheduled task %s: %s" % (
                     entry.name, exc))
@@ -237,6 +255,10 @@ class Scheduler(UserDict):
     def schedule(self):
         return self.get_schedule()
 
+    @property
+    def info(self):
+        return ""
+
 
 class PersistentScheduler(Scheduler):
     persistence = shelve
@@ -263,6 +285,10 @@ class PersistentScheduler(Scheduler):
         self.sync()
         self._store.close()
 
+    @property
+    def info(self):
+        return "    . db -> %s" % (self.schedule_filename, )
+
 
 class Service(object):
     scheduler_cls = PersistentScheduler
@@ -315,15 +341,21 @@ class Service(object):
         self._shutdown.set()
         wait and self._stopped.wait()           # block until shutdown done.
 
+    def get_scheduler(self, lazy=False):
+        filename = self.schedule_filename
+        scheduler = instantiate(self.scheduler_cls,
+                                      schedule_filename=filename,
+                                      logger=self.logger,
+                                      max_interval=self.max_interval,
+                                      lazy=lazy)
+        if not lazy:
+            scheduler.update_from_dict(self.schedule)
+        return scheduler
+
     @property
     def scheduler(self):
         if self._scheduler is None:
-            filename = self.schedule_filename
-            self._scheduler = instantiate(self.scheduler_cls,
-                                          schedule_filename=filename,
-                                          logger=self.logger,
-                                          max_interval=self.max_interval)
-            self._scheduler.update_from_dict(self.schedule)
+            self._scheduler = self.get_scheduler()
         return self._scheduler
 
 
