@@ -67,6 +67,7 @@
     terminated and replaced by a new worker.
 
 """
+import sys
 import multiprocessing
 
 from celery.bin.base import Command, Option
@@ -77,7 +78,7 @@ class WorkerCommand(Command):
     def run(self, *args, **kwargs):
         from celery.apps.worker import Worker
         kwargs["defaults"] = self.defaults
-        return Worker(*args, **kwargs).run()
+        return Worker(**kwargs).run()
 
     def get_options(self):
         conf = self.defaults
@@ -156,5 +157,23 @@ def main():
     worker = WorkerCommand()
     worker.execute_from_commandline()
 
+
+def windows_main():
+    sys.stderr.write("""
+
+The celeryd command does not work on Windows.
+
+Instead, please use:
+
+    ..> python -m celery.bin.celeryd
+
+You can also supply arguments:
+
+    ..> python -m celery.bin.celeryd --concurrency=10 --loglevel=DEBUG
+
+
+    """.strip())
+
+
 if __name__ == "__main__":          # pragma: no cover
     main()
