@@ -31,6 +31,8 @@ _DEFAULTS = {
     "BROKER_USER": "guest",
     "BROKER_PASSWORD": "guest",
     "BROKER_VHOST": "/",
+    "CELERY_REDIRECT_STDOUTS": True,
+    "CELERY_REDIRECT_STDOUTS_LEVEL": "WARNING",
     "CELERY_RESULT_BACKEND": "database",
     "CELERY_ALWAYS_EAGER": False,
     "CELERY_EAGER_PROPAGATES_EXCEPTIONS": False,
@@ -64,6 +66,7 @@ _DEFAULTS = {
     "CELERYD_LOG_COLOR": False,
     "CELERYD_LOG_LEVEL": "WARN",
     "CELERYD_LOG_FILE": None,                       # stderr
+    "CELERYBEAT_SCHEDULER": "celery.beat.PersistentScheduler",
     "CELERYBEAT_SCHEDULE": {},
     "CELERYD_STATE_DB": None,
     "CELERYD_ETA_SCHEDULER_PRECISION": 1,
@@ -138,6 +141,8 @@ def prepare(m, source=settings, defaults=_DEFAULTS):
     m.IGNORE_RESULT = _get("CELERY_IGNORE_RESULT")
     m.TRACK_STARTED = _get("CELERY_TRACK_STARTED")
     m.ACKS_LATE = _get("CELERY_ACKS_LATE")
+    m.REDIRECT_STDOUTS = _get("CELERY_REDIRECT_STDOUTS")
+    m.REDIRECT_STDOUTS_LEVEL = _get("CELERY_REDIRECT_STDOUTS_LEVEL")
 
     # Make sure TASK_RESULT_EXPIRES is a timedelta.
     if isinstance(m.TASK_RESULT_EXPIRES, int):
@@ -255,6 +260,7 @@ def prepare(m, source=settings, defaults=_DEFAULTS):
     m.CELERYBEAT_LOG_LEVEL = _get("CELERYBEAT_LOG_LEVEL")
     m.CELERYBEAT_LOG_FILE = _get("CELERYBEAT_LOG_FILE")
     m.CELERYBEAT_SCHEDULE = _get("CELERYBEAT_SCHEDULE")
+    m.CELERYBEAT_SCHEDULER = _get("CELERYBEAT_SCHEDULER")
     m.CELERYBEAT_SCHEDULE_FILENAME = _get("CELERYBEAT_SCHEDULE_FILENAME")
     m.CELERYBEAT_MAX_LOOP_INTERVAL = _get("CELERYBEAT_MAX_LOOP_INTERVAL")
 
