@@ -211,6 +211,10 @@ class Task(object):
         The global default can be overriden by the :setting:`CELERY_ACKS_LATE`
         setting.
 
+    .. attribute:: expires
+
+        Default task expiry time in seconds or a :class:`~datetime.datetime`.
+
     """
     __metaclass__ = TaskType
 
@@ -235,6 +239,7 @@ class Task(object):
     disable_error_emails = False                                    # FIXME
     max_retries = 5
     default_retry_delay = 3 * 60
+    expires = None
     serializer = conf.TASK_SERIALIZER
     rate_limit = conf.DEFAULT_RATE_LIMIT
     backend = default_backend
