@@ -2,7 +2,6 @@ from datetime import datetime
 
 from celery import conf
 from celery import log
-from celery.backends import default_backend
 from celery.registry import tasks
 from celery.utils import timeutils
 from celery.worker import state
@@ -12,18 +11,6 @@ from celery.worker.control.registry import Panel
 TASK_INFO_FIELDS = ("exchange", "routing_key", "rate_limit")
 
 
-@Panel.register
-def diagnose(panel, timeout=None, **kwargs):
-    info = panel.listener.pool.diagnose(timeout=timeout)
-
-    if info["waiting"]:
-        panel.logger.error("Diagnose failed: %r" % (info, ))
-        return {"error": info}
-
-    panel.logger.info("Diagnose complete: %r" % (info, ))
-    return {"ok": info}
-
-
 @Panel.register
 def revoke(panel, task_id, **kwargs):
     """Revoke task by task id."""
@@ -120,7 +107,8 @@ def dump_schedule(panel, safe=False, **kwargs):
     for item in schedule.info():
         scheduled_tasks.append({"eta": item["eta"],
                                 "priority": item["priority"],
-                                "request": item["item"].info(safe=safe)})
+                                "request":
+                                    item["item"].args[0].info(safe=safe)})
     return scheduled_tasks
 
 
@@ -184,3 +172,25 @@ def ping(panel, **kwargs):
 def shutdown(panel, **kwargs):
     panel.logger.critical("Got shutdown from remote.")
     raise SystemExit("Got shutdown from remote")
+
+
+@Panel.register
+def add_consumer(panel, queue=None, exchange=None, exchange_type="direct",
+        routing_key=None, **options):
+    cset = panel.listener.task_consumer
+    declaration = dict(queue=queue,
+                       exchange=exchange,
+                       exchange_type=exchange_type,
+                       routing_key=routing_key,
+                       **options)
+    cset.add_consumer_from_dict(**declaration)
+    cset.consume()
+    panel.logger.info("Started consuming from %r" % (declaration, ))
+    return {"ok": "started consuming from %s" % (queue, )}
+
+
+@Panel.register
+def cancel_consumer(panel, queue=None, **_):
+    cset = panel.listener.task_consumer
+    cset.cancel_by_queue(queue)
+    return {"ok": "no longer consuming from %s" % (queue, )}
